﻿#include <algorithm>
#include <ctime>
#include <iostream>
#include <map>
#include <set>
#include <string>
#include <vector>

#define int long long
#define fastio ios_base::sync_with_stdio(0); cin.tie(0); cout.tie(0)

using namespace std;

struct node {
	node* left, * right;
	int key, priority, f, sz;
	node(int key) : key(key), left(nullptr), right(nullptr), priority((rand() << 16) + rand()), f(key), sz(1) {}
};

int f(node* v) {
	if (v == nullptr)
		return 0;
	return v->f;
}

int sz(node* v) {
	if (v == nullptr)
		return 0;
	return v->sz;
}

void up(node* v) {
	if (v == nullptr)
		return;
	v->f = max(v->key, max(f(v->left), f(v->right)));
	v->sz = sz(v->left) + sz(v->right) + 1;
}

pair<node*, node*> split(node* root, int k) {
	if (root == nullptr)
		return { nullptr, nullptr };
	if (root->key < k) {
		auto p = split(root->right, k);
		root->right = p.first;
		up(root);
		return { root, p.second };
	}
	else {
		auto p = split(root->left, k);
		root->left = p.second;
		up(root);
		return { p.first, root };
	}
}

node* merge(node* l, node* r) {
	if (l == nullptr)
		return r;
	if (r == nullptr)
		return l;
	if (l->priority > r->priority) {
		l->right = merge(l->right, r);
		up(l);
		return l;
	}
	else {
		r->left = merge(l, r->left);
		up(r);
		return r;
	}
}

node* add(node* root, int k) {
	auto p = split(root, k);
	root = merge(p.first, new node(k));
	root = merge(root, p.second);
	return root;
}

node* erase(node* root, int k) {
	if (root == nullptr)
		return nullptr;
	if (root->key == k) {
		root = merge(root->left, root->right);
		up(root);
		return root;
	}
	if (root->key < k) {
		root->right = erase(root->right, k);
		up(root);
		return root;
	}
	else {
		root->left = erase(root->left, k);
		up(root);
		return root;
	}
}

int kth(node* root, int k) {
	if (root == nullptr)
		return 0;
	if (sz(root->left) + 1 == k)
		return root->key;
	if (sz(root->left) + 1 < k)
		return kth(root->right, k - sz(root->left) - 1);
	else
		return kth(root->left, k);
}

int get(node* root, int k) {
	int val = kth(root, k);
	auto p = split(root, val + 1);
	int res = f(p.first);
	root = merge(p.first, p.second);
	return res;
}

vector<int> v;

node* root = nullptr;

signed main() {
	fastio;
	srand(time(0));
	int n, k, m;
	cin >> n >> k >> m;
	for (int i = 0; i < n; ++i) {
		int x;
		cin >> x;
		v.push_back(x);
	}
	int res = 0;
	for (int i = 0; i < k; ++i)
		root = add(root, v[i]);
	for (int i = 0; i <= n - k; ++i) {
		res = max(res, get(root, m));
		root = erase(root, v[i]);
		if (i != n - k)
			root = add(root, v[i + k]);
	}
	int ans = 0;
	for (auto i : v)
		if (i > res)
			ans += i;
	cout << ans - res;
}